@@ -277,7 +277,7 @@ gupnp_root_device_constructor (GType                  type,
         GUPnPContext *context;
         const char *description_path, *description_dir, *udn;
         char *desc_path, *location, *usn, *relative_location;
-        int i;
+        unsigned int i;
         GUPnPXMLDoc *description_doc;
         xmlNode *root_element, *element;
         SoupURI *url_base;
@@ -416,9 +416,7 @@ gupnp_root_device_constructor (GType                  type,
                                        NULL);
 
         /* Host the description file and dir */
-        gupnp_context_host_path (context,
-                                 desc_path,
-                                 relative_location);
+        gupnp_context_host_path (context, desc_path, relative_location);
         gupnp_context_host_path (context, device->priv->description_dir, "");
 
         /* Generate full location */
@@ -441,7 +439,7 @@ gupnp_root_device_constructor (GType                  type,
                       "url-base", url_base,
                       NULL);
 
-	soup_uri_free (url_base);
+        soup_uri_free (url_base);
 
         /* Create resource group */
         device->priv->group = gssdp_resource_group_new (GSSDP_CLIENT (context));
@@ -480,7 +478,7 @@ gupnp_root_device_class_init (GUPnPRootDeviceClass *klass)
         g_type_class_add_private (klass, sizeof (GUPnPRootDevicePrivate));
 
         /**
-         * GUPnPRootDevice:description-doc
+         * GUPnPRootDevice:description-doc:
          *
          * Device description document. Constructor property.
          **/
@@ -498,7 +496,7 @@ gupnp_root_device_class_init (GUPnPRootDeviceClass *klass)
                                       G_PARAM_STATIC_BLURB));
 
         /**
-         * GUPnPRootDevice:description-path
+         * GUPnPRootDevice:description-path:
          *
          * The path to device description document. This could either be an
          * absolute path or path relative to GUPnPRootDevice:description-dir.
@@ -517,7 +515,7 @@ gupnp_root_device_class_init (GUPnPRootDeviceClass *klass)
                                       G_PARAM_STATIC_BLURB));
 
         /**
-         * GUPnPRootDevice:description-dir
+         * GUPnPRootDevice:description-dir:
          *
          * The path to directory where description documents are provided.
          **/
@@ -536,7 +534,7 @@ gupnp_root_device_class_init (GUPnPRootDeviceClass *klass)
                                       G_PARAM_STATIC_BLURB));
 
         /**
-         * GUPnPRootDevice:available
+         * GUPnPRootDevice:available:
          *
          * TRUE if this device is available.
          **/
@@ -582,7 +580,7 @@ gupnp_root_device_new (GUPnPContext *context,
 }
 
 /**
- * gupnp_root_device_new_full
+ * gupnp_root_device_new_full:
  * @context: A #GUPnPContext
  * @factory: A #GUPnPResourceFactory
  * @description_doc: Device description document, or %NULL
@@ -617,7 +615,7 @@ gupnp_root_device_new_full (GUPnPContext         *context,
 }
 
 /**
- * gupnp_root_device_set_available
+ * gupnp_root_device_set_available:
  * @root_device: A #GUPnPRootDevice
  * @available: %TRUE if @root_device should be available
  *
@@ -637,7 +635,7 @@ gupnp_root_device_set_available (GUPnPRootDevice *root_device,
 }
 
 /**
- * gupnp_root_device_get_available
+ * gupnp_root_device_get_available:
  * @root_device: A #GUPnPRootDevice
  *
  * Get whether or not @root_device is available (announcing its presence).
@@ -653,7 +651,7 @@ gupnp_root_device_get_available (GUPnPRootDevice *root_device)
 }
 
 /**
- * gupnp_root_device_get_relative_location
+ * gupnp_root_device_get_relative_location:
  * @root_device: A #GUPnPRootDevice
  *
  * Get the relative location of @root_device.
@@ -669,7 +667,7 @@ gupnp_root_device_get_relative_location (GUPnPRootDevice *root_device)
 }
 
 /**
- * gupnp_root_device_get_description_path
+ * gupnp_root_device_get_description_path:
  * @root_device: A #GUPnPRootDevice
  *
  * Get the path to the device description document of @root_device.
@@ -685,7 +683,7 @@ gupnp_root_device_get_description_path (GUPnPRootDevice *root_device)
 }
 
 /**
- * gupnp_root_device_get_description_dir
+ * gupnp_root_device_get_description_dir:
  * @root_device: A #GUPnPRootDevice
  *
  * Get the path to the directory containing description documents related to
